pub struct Machine<H, I, S>{ /* private fields */ }Expand description
A box containing the sample with a given temperature and field.
Implementations
Sourceimpl<H, I, S> Machine<H, I, S>
impl<H, I, S> Machine<H, I, S>
Sourcepub fn new(
thermostat: Thermostat<S>,
hamiltonian: H,
integrator: I,
instruments: Vec<Box<dyn Instrument<H, S>>>,
state: State<S>,
) -> Self
pub fn new( thermostat: Thermostat<S>, hamiltonian: H, integrator: I, instruments: Vec<Box<dyn Instrument<H, S>>>, state: State<S>, ) -> Self
Create a new machine with a given temperature, field, hamiltonian,
Sourcepub fn thermostat(&self) -> &Thermostat<S>
pub fn thermostat(&self) -> &Thermostat<S>
Get the current thermostat of the machine.
Sourcepub fn set_thermostat(&mut self, thermostat: Thermostat<S>)
pub fn set_thermostat(&mut self, thermostat: Thermostat<S>)
Set the thermostat of the machine.
Sourcepub fn relax_for<R: Rng>(
&mut self,
rng: &mut R,
steps: usize,
) -> MachineResult<()>
pub fn relax_for<R: Rng>( &mut self, rng: &mut R, steps: usize, ) -> MachineResult<()>
Relax the machine for a given number of steps.
Sourcepub fn measure_for<R: Rng>(
&mut self,
rng: &mut R,
steps: usize,
) -> MachineResult<()>
pub fn measure_for<R: Rng>( &mut self, rng: &mut R, steps: usize, ) -> MachineResult<()>
Measure the machine for a given number of steps.