Program

Trait Program 

pub trait Program {
    // Required method
    fn run<R, I, H, S>(
        &self,
        rng: &mut R,
        machine: &mut Machine<H, I, S>,
    ) -> ProgramResult<()>
       where R: Rng,
             I: Integrator<S>,
             H: Hamiltonian<S>,
             S: Spin;
}
A program is a sequence of steps that can be run on a system.

Required Methods

fn run<R, I, H, S>( &self, rng: &mut R, machine: &mut Machine<H, I, S>, ) -> ProgramResult<()>
where R: Rng, I: Integrator<S>, H: Hamiltonian<S>, S: Spin,

Run the program on a system returning the last state.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors